Nitrogen partitioning and remobilization in relation to leaf senescence, grain yield and grain nitrogen concentration in wheat cultivars ☆
By O. Gaju, V. Allard, Pierre Martre, Jacques Le Gouis, D. Moreau, M. Bogard, Stella Hubbart, M. Foulkes. 2014
297 citations recorded by the source corpus.
Abstract Our objective was to investigate the determinants of genetic variation in N accumulation, N partitioning and N remobilization to the grain post-flowering and associations with flag-leaf senescence, grain yield and grain N% in 16 wheat cultivars grown under high N (HN) and low N (LN) conditions in the UK and France. Overall, cultivars ranged in leaf lamina N accumulation at anthesis from 5.32 to 8.03 g N m−2 at HN and from 2.69 to 3.62 g N m−2 at LN, and for the stem-and leaf-sheath from 5.45 to 7.25 g N m−2 at HN and from 2.55 to 3.41 g N m−2 at LN (P
Subfields: Agronomy and Crop Science, Plant Science
View Paper: https://www.semanticscholar.org/paper/5bf7ddda2ceb04730b2d8a114f0d453d853195ba
How researchers see this paper
The researchers whose trusted networks rank it highest, strongest advocate first. Every researcher gets a different order.
In Agronomy and Crop Science
In Plant Science
- Y. Moënne‐Loccoz
- Paul C. Struik
- John Foulkes
- Pierre Martre
- Jacques Le Gouis
- Karine Chenu
- Philippe P. Debaeke
- B. Hirel
Citations in the corpus
- Breeding for increased nitrogen‐use efficiency: a review for wheat (T. aestivum L.) (2016, background): “Post-anthesis N remobilization and senescence dynamics In wheat, 35–42% of the N in the above-ground crop at anthesis is in the leaf lamina, 14–20% in the leaf sheath, 20–31% in the true stem and 16–23% in the ear under optimal N supply (Pask et al. 2012, Barraclough et al. 2014, Gaju et al. 2014).”
- Diverse concepts of breeding for nitrogen use efficiency. A review (2017, background): “At low N growing conditions, lamina N remobilization seemed to cause genetic variability in grain N% but not in grain yield (Gaju et al. 2014).”
- Model-assisted phenotyping and ideotype design (2015, result): “These results are consistent with both a previous sensitivity analysis of Siriusquality1 (martre et al., 2007), and experimental results (Shearman et al., 2005; Gaju et al., 2014).”